-- TobiiSettingsManager.lua
-- Written by Almagnus1
-- Serializes/Deserializes settings for Tobii

import "Turbine";
import "Turbine.UI";

TobiiSettingsManager = class( Turbine.Object );

function TobiiSettingsManager:Constructor()
	-- constants
	local width = 422;
	local height = 303;
	local edgePadding = 50;

	-- create setting datastructure with default values
	self.Settings = {};
	self.Settings.Location = {};
	self.Settings.Location.X = Turbine.UI.Display:GetWidth() - width - edgePadding;
	self.Settings.Location.Y = Turbine.UI.Display:GetHeight() - height - edgePadding;
	self.Settings.Size = {};
	self.Settings.Size.Width = width;
	self.Settings.Size.Height = height;
	self.Settings.Version = "2.0.1"; -- current version
	self.Settings.StartVisibility = true;
	self.Settings.ShowUsed = true;
end

function TobiiSettingsManager:Load()
	local location = Turbine.PluginData.Load( Turbine.DataScope.Character, "TobiiLocation" );
	local settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "TobiiSettings" );
	local width = Turbine.UI.Display:GetWidth();
	local height = Turbine.UI.Display:GetHeight();

	-- 1.0 data translation
	if ( ( type( location ) == "table" )
		and ( type( location.x ) == "number" )
		and ( location.x < width )
		and ( type( location.y ) == "number" )
		and ( location.y < height ) )
	then 
		self.Settings.Location.X = location.x;
		self.Settings.Location.Y = location.y;
	end
	
	if ( ( type( settings ) == "table" )
		and ( type( settings.Location ) == "table" )
		and ( type( settings.Location.X ) == "number" )
		and ( settings.Location.X < width )
		and ( type( settings.Location.Y ) == "number" )
		and ( settings.Location.Y < height )
		and ( type( settings.Size ) == "table" )
		and ( type( settings.Size.Width ) == "number" )
		and ( ( settings.Size.Width + settings.Location.X ) <= ( width + 1 ) )
		and ( type( settings.Size.Height ) == "number" )
		and ( ( settings.Size.Height + settings.Location.Y ) <= ( height + 1 ) )
		and ( type( settings.Version ) == "string" )
		and ( type( settings.StartVisibility ) == "boolean" ) )
	then
		-- translations to the current save format
		if ( settings.Version == "2.0.0" ) then
			-- no format changes, will automatically update to the newest version number
		else
			-- default load behavior
		end
		
		self.Settings.Location.X = settings.Location.X;
		self.Settings.Location.Y = settings.Location.Y;
		self.Settings.Size.Width = settings.Size.Width;
		self.Settings.Size.Height = settings.Size.Height;
		self.Settings.StartVisibility = settings.StartVisibility;
		self.Settings.ShowUsed = settings.ShowUsed;
	end
end

function TobiiSettingsManager:Save()
	Turbine.PluginData.Save( Turbine.DataScope.Character, "TobiiSettings", self.Settings );
end